summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/associationwidget.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/associationwidget.cpp')
-rw-r--r--umbrello/umbrello/associationwidget.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/umbrello/umbrello/associationwidget.cpp b/umbrello/umbrello/associationwidget.cpp
index 3b4468f6..6ded541d 100644
--- a/umbrello/umbrello/associationwidget.cpp
+++ b/umbrello/umbrello/associationwidget.cpp
@@ -775,7 +775,7 @@ void AssociationWidget::setUMLAssociation (UMLAssociation * assoc)
umla->nrof_parent_widgets--;
// we are the last "owner" of this association, so delete it
// from the tqparent UMLDoc, and as a stand-alone
//DISCUSS: Should we really do this?
// It implies that an association's existence is ONLY
// governed by its existence on at least one diagram.
@@ -785,16 +785,16 @@ void AssociationWidget::setUMLAssociation (UMLAssociation * assoc)
// relies on (at least the way it's implemented now)
// ANSWER: yes, we *should* do this.
// This only implies that IF an association once 'belonged'
// to one or more tqparent associationwidgets, then it must 'die' when the
// last widget does. UMLAssociations which never had a tqparent
// in the first place wont be affected by this code, and can happily
// live on without a tqparent.
//DISCUSS: Sorry Brian, but this breaks cut/paste.
// In particular, cut/paste means that the UMLAssociation _does_
// have the assocwidget tqparent - the only means of doing a cut/paste
// on the diagram is via the widgets. I.e. in practice there is no
// such thing as an "orphan" UMLAssociation.
// BTW, IMHO the concept of a widget being the tqparent of a UML object
// is fundamentally flawed. Widgets are pure presentation - they can
// come and go at a whim. If at all, the widgets could be considered
// tqchildren of the corresponding UML object.
@@ -3121,14 +3121,14 @@ void AssociationWidget::setUMLObject(UMLObject *obj) {
setOperation(dynamic_cast<UMLOperation *>(obj));
break;
case Uml::ot_Attribute:
- klass = static_cast<UMLClassifier*>(obj->tqparent());
+ klass = static_cast<UMLClassifier*>(obj->parent());
connect(klass, TQT_SIGNAL(attributeRemoved(UMLClassifierListItem*)),
this, TQT_SLOT(slotAttributeRemoved(UMLClassifierListItem*)));
attr = static_cast<UMLAttribute*>(obj);
connect(attr, TQT_SIGNAL(attributeChanged()), this, TQT_SLOT(slotAttributeChanged()));
break;
case Uml::ot_EntityAttribute:
- ent = static_cast<UMLEntity*>(obj->tqparent());
+ ent = static_cast<UMLEntity*>(obj->parent());
connect(ent, TQT_SIGNAL(entityAttributeRemoved(UMLClassifierListItem*)),
this, TQT_SLOT(slotAttributeRemoved(UMLClassifierListItem*)));
break;
@@ -775,7 +775,7 @@ void AssociationWidget::setUMLAssociation (UMLAssociation * assoc)
umla->nrof_parent_widgets--;
// we are the last "owner" of this association, so delete it
- // from the tqparent UMLDoc, and as a stand-alone
+ // from the parent UMLDoc, and as a stand-alone
//DISCUSS: Should we really do this?
// It implies that an association's existence is ONLY
@@ -785,16 +785,16 @@ void AssociationWidget::setUMLAssociation (UMLAssociation * assoc)
// ANSWER: yes, we *should* do this.
// This only implies that IF an association once 'belonged'
- // to one or more tqparent associationwidgets, then it must 'die' when the
- // last widget does. UMLAssociations which never had a tqparent
+ // to one or more parent associationwidgets, then it must 'die' when the
+ // last widget does. UMLAssociations which never had a parent
// in the first place wont be affected by this code, and can happily
@@ -785,16 +785,16 @@ void AssociationWidget::setUMLAssociation (UMLAssociation * assoc)
// in the first place wont be affected by this code, and can happily
- // live on without a tqparent.
+ // live on without a parent.
//DISCUSS: Sorry Brian, but this breaks cut/paste.
// In particular, cut/paste means that the UMLAssociation _does_
@@ -785,16 +785,16 @@ void AssociationWidget::setUMLAssociation (UMLAssociation * assoc)
//DISCUSS: Sorry Brian, but this breaks cut/paste.
// In particular, cut/paste means that the UMLAssociation _does_
- // have the assocwidget tqparent - the only means of doing a cut/paste
+ // have the assocwidget parent - the only means of doing a cut/paste
// on the diagram is via the widgets. I.e. in practice there is no
// such thing as an "orphan" UMLAssociation.
@@ -785,16 +785,16 @@ void AssociationWidget::setUMLAssociation (UMLAssociation * assoc)
// on the diagram is via the widgets. I.e. in practice there is no
// such thing as an "orphan" UMLAssociation.
- // BTW, IMHO the concept of a widget being the tqparent of a UML object
+ // BTW, IMHO the concept of a widget being the parent of a UML object
// is fundamentally flawed. Widgets are pure presentation - they can
// come and go at a whim. If at all, the widgets could be considered